# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2019-11-28 15:03
from __future__ import unicode_literals

from django.db import migrations, models
import djangoldp.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CodeFragment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('title', models.CharField(max_length=255)),
                ('body', models.TextField()),
                ('head', models.TextField(blank=True)),
                ('description', models.TextField(blank=True)),
                ('order', models.PositiveIntegerField(unique=True)),
            ],
            options={
                'ordering': ['order'],
            },
        ),
    ]
