# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2019-12-18 10:33
from __future__ import unicode_literals

from django.db import migrations

def combine_names(apps, schema_editor):
    CodeFragment = apps.get_model('djangoldp_editor', 'CodeFragment')
    HelloWorld = apps.get_model('djangoldp_editor', 'HelloWorld')
    User = apps.get_model('djangoldp_editor', 'User')


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_editor', '0006_auto_20191212_1510'),
    ]

    operations = [
         migrations.RunPython(combine_names),
    ]
