# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2019-12-12 15:10
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_editor', '0005_auto_20191212_1454'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='user',
            options={},
        ),
    ]
